@@ -32,6 +32,26 @@ gql_create_global_env_var = """
   }}
 """
 
+
+gql_update_env_var = """
+mutation($id: UUID, $entityId: UUID, $name: String!, $scope: EnvVarScope!, $value: String, $description: String, 
+        $isPassword: Boolean!)  {
+            saveEnvironmentVariable(
+                entityId: $entityId
+                environmentVariable: {
+                    id: $id
+                    name: $name
+                    scope: $scope
+                    value: $value
+                    description: $description
+                    isPassword:$isPassword
+        
+    }){
+        id
+    }}
+"""
+
+
 gql_delete_env_var = """
   mutation {{
     deleteEnvironmentVariable (
@@ -40,6 +60,8 @@ gql_delete_env_var = """
   }}
 """
 
+
+
 gql_get_project_env_vars = """
   {{
     projectEnvironmentVariables(projectId: "{0}"){{
@@ -71,6 +93,9 @@ gql_create_project_env_var = """
 """
 
 
+
+
+
 #   ____ _           _
 #  / ___| |_   _ ___| |_ ___ _ __
 # | |   | | | | / __| __/ _ \ '__|
